const { ipcRenderer, webFrame } = require('electron');

console.log('Initializing native wrapper bridge');

window.NativeWrapperBridge = {
	setZoomLevel: setZoomLevel,
	getPathSeparator: getPathSeparator,
	getHomeDir: getHomeDir,
	getElectronVersion: getElectronVersion,
	setTaskbarProgress: setTaskbarProgress,
	localFiles: localFiles
};

function setZoomLevel(zoomLevel) {
	webFrame.setZoomFactor(zoomLevel / 100);
}

function getPathSeparator() {
	return new Promise(resolve => {
		ipcRenderer.send('req-path-separator');
		ipcRenderer.on('res-path-separator', (event, args) => {
			resolve(args);
		});
	});
}

function getHomeDir() {
	return new Promise(resolve => {
		ipcRenderer.send('req-home-dir');
		ipcRenderer.on('res-home-dir', (event, args) => {
			resolve(args);
		});
	});
}

function getElectronVersion() {
	return new Promise(resolve => {
		ipcRenderer.send('req-electron-version');
		ipcRenderer.on('res-electron-version', (event, args) => {
			resolve(args);
		});
	});
}

function setTaskbarProgress(value) {
	ipcRenderer.send('req-set-taskbar-progress', value);
}

function localFiles(path) {
	return new Promise(resolve => {
		ipcRenderer.send('req-local-files', path);
		ipcRenderer.on('res-local-files', (event, args) => {
			resolve(args);
		});
	});
}
